@@ -3,11 +3,10 @@ from typing import Union
 from zoneinfo import ZoneInfo
 
 import pytest
-from parameterized import parameterized  # type: ignore[import]
+from parameterized import parameterized  # type: ignore[import-untyped]
 from pydantic import BaseModel, ValidationError
 
 from heliclockter import DateTimeTzT, datetime_local, datetime_tz, datetime_utc, timedelta
-
 from tests.shared import datetime_cet
 
 
@@ -39,67 +38,67 @@ TestModelT = Union[DatetimeTZModel, DatetimeUTCModel, DatetimeCETModel]
     [
         # UTC tests
         (
-            '2021-01-10T10:00:00',
-            datetime_utc(2021, 1, 10, 10, 00, 00, tzinfo=ZoneInfo('UTC')),
+            "2021-01-10T10:00:00",
+            datetime_utc(2021, 1, 10, 10, 00, 00, tzinfo=ZoneInfo("UTC")),
             DatetimeUTCModel,
         ),
         (
-            '2021-01-10T10:00:00+04:00',
-            datetime_utc(2021, 1, 10, 6, 00, 00, tzinfo=ZoneInfo('UTC')),
+            "2021-01-10T10:00:00+04:00",
+            datetime_utc(2021, 1, 10, 6, 00, 00, tzinfo=ZoneInfo("UTC")),
             DatetimeUTCModel,
         ),
         (
-            '2021-01-10T10:00:00+00:00',
-            datetime_utc(2021, 1, 10, 10, 00, 00, tzinfo=ZoneInfo('UTC')),
+            "2021-01-10T10:00:00+00:00",
+            datetime_utc(2021, 1, 10, 10, 00, 00, tzinfo=ZoneInfo("UTC")),
             DatetimeUTCModel,
         ),
         (
-            '2021-01-10T10:00:00-04:00',
-            datetime_utc(2021, 1, 10, 14, 00, 00, tzinfo=ZoneInfo('UTC')),
+            "2021-01-10T10:00:00-04:00",
+            datetime_utc(2021, 1, 10, 14, 00, 00, tzinfo=ZoneInfo("UTC")),
             DatetimeUTCModel,
         ),
         # TZ tests
         (
-            '2021-01-10T10:00:00+04:00',
+            "2021-01-10T10:00:00+04:00",
             datetime_tz(2021, 1, 10, 10, 0, tzinfo=timezone(timedelta(hours=4))),
             DatetimeTZModel,
         ),
         (
-            '2021-01-10T10:00:00-04:00',
+            "2021-01-10T10:00:00-04:00",
             datetime_tz(2021, 1, 10, 10, 0, tzinfo=timezone(timedelta(hours=-4))),
             DatetimeTZModel,
         ),
         # CET tests
         (
-            '2021-01-10T10:00:00',
-            datetime_cet(2021, 1, 10, 10, 00, 00, tzinfo=ZoneInfo('CET')),
+            "2021-01-10T10:00:00",
+            datetime_cet(2021, 1, 10, 10, 00, 00, tzinfo=ZoneInfo("CET")),
             DatetimeCETModel,
         ),
         (
-            '2021-01-10T10:00:00+04:00',
-            datetime_cet(2021, 1, 10, 7, 00, 00, tzinfo=ZoneInfo('CET')),
+            "2021-01-10T10:00:00+04:00",
+            datetime_cet(2021, 1, 10, 7, 00, 00, tzinfo=ZoneInfo("CET")),
             DatetimeCETModel,
         ),
         (
-            '2021-01-10T10:00:00+00:00',
-            datetime_cet(2021, 1, 10, 11, 00, 00, tzinfo=ZoneInfo('CET')),
+            "2021-01-10T10:00:00+00:00",
+            datetime_cet(2021, 1, 10, 11, 00, 00, tzinfo=ZoneInfo("CET")),
             DatetimeCETModel,
         ),
         (
-            '2021-01-10T10:00:00-04:00',
-            datetime_cet(2021, 1, 10, 15, 00, 00, tzinfo=ZoneInfo('CET')),
+            "2021-01-10T10:00:00-04:00",
+            datetime_cet(2021, 1, 10, 15, 00, 00, tzinfo=ZoneInfo("CET")),
             DatetimeCETModel,
         ),
     ]
 )
 def test_datetime_parsing(test_str: str, expectation: DateTimeTzT, model: TestModelT) -> None:
-    parsed_model = model.parse_obj({'dt': test_str})
+    parsed_model = model.model_validate({"dt": test_str})
     assert isinstance(parsed_model.dt, type(expectation))
     assert parsed_model.dt == expectation
 
 
 def test_datetime_local_parsing() -> None:
-    parsed_model = DatetimeLocalModel.parse_obj({'dt': '2021-01-10T10:00:00-04:00'})
+    parsed_model = DatetimeLocalModel.model_validate({"dt": "2021-01-10T10:00:00-04:00"})
     assert isinstance(parsed_model.dt, datetime_local)
 
 
@@ -116,12 +115,12 @@ def test_parse_datetime_utc_as_datetime_tz() -> None:
 
 def test_parse_datetime_tz_without_timezone() -> None:
     with pytest.raises(ValidationError):
-        DatetimeTZModel.parse_obj({'dt': '2021-01-10T10:00:00'})
+        DatetimeTZModel.model_validate({"dt": "2021-01-10T10:00:00"})
 
 
 def test_parse_datetime_instance() -> None:
-    dt = datetime(2021, 1, 10, 10, 0, 0, tzinfo=ZoneInfo('UTC'))
-    DatetimeTZModel.parse_obj({'dt': dt})
+    dt = datetime(2021, 1, 10, 10, 0, 0, tzinfo=ZoneInfo("UTC"))
+    DatetimeTZModel.model_validate({"dt": dt})
 
     parsed_tz_model = DatetimeTZModel(dt=dt)  # type: ignore[arg-type]
     assert isinstance(parsed_tz_model.dt, datetime_tz)
